#
# spec file for package orthanc-postgresql
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019-2025 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthanc-postgresql
Summary:        Database plugin for Orthanc
License:        AGPL-3.0-or-later
Group:          Productivity/Databases/Tools
Version:        7.2
Release:        1.1
URL:            https://orthanc-server.com
Source0:        https://orthanc.uclouvain.be/downloads/sources/%{name}/OrthancPostgreSQL-%{version}.tar.gz
Source1:        orthanc-postgresql-readme.SUSE
Source2:        postgresql.json
BuildRequires:  cmake
BuildRequires:  e2fsprogs-devel
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  googletest-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_atomic-devel >= 1.66
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  openssl-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  postgresql-devel
BuildRequires:  protobuf-devel
#TW/Leap 15.2
%if 0%{?sle_version} > 150100 || 0%{?suse_version} > 1500
BuildRequires:  postgresql-server-devel
%endif
BuildRequires:  unzip
BuildRequires:  uuid-devel
BuildRequires:  zlib-devel

Requires:       orthanc
Requires:       postgresql-server

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PostgreSQL Database plugin for Orthanc, replaces SQLite database

%prep

%autosetup -n OrthancPostgreSQL-%{version}

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
%cmake ../PostgreSQL \
       -DALLOW_DOWNLOADS=ON \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install

mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

%cmake_install

# architecture dependet files should not be in /usr/share...
# create a directory
mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#Link from lib64 to orthanc plugin-directory, where it is expected
ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancPostgreSQLIndex.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancPostgreSQLIndex.so

ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancPostgreSQLStorage.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancPostgreSQLStorage.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/*.so

cp %{S:1} %{S:2} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*

%changelog
* Thu Feb 27 2025 Axel Braun <axel.braun@gmx.de>
- version 7.2
  * Optimized the SQL query that is maintaing the childCount
    when new instances are ingested.
  * New configuration "AllowInconsistentChildCounts" to speed
    up childCount computation.  If set to true, childCount values
    of recently ingested resources will be incorrect until the next
    execution of the DB Housekeeping thread (defined by "HousekeepingInterval"
  - default value is 1s)
  * Fixed high memory usage due to caching of too many
    prepared SQL statement when using since & limit.
  * Removed duplicate comparison in find SQL queries.
  * Now returning results when e.g, ordering instances against a metadata they don't have.
* Fri Jan 24 2025 Axel Braun <axel.braun@gmx.de>
- version 7.1
  * fixing the searches with a ModalitiesInStudy filter.
* Sat Dec 21 2024 Axel Braun <axel.braun@gmx.de>
- version 7.0
  * support for the ExtendedFind extension
  * new DB schema revision (automatic conversion)
* Thu Mar 28 2024 Axel Braun <axel.braun@gmx.de>
- version 6.2
  * DB schema revision: 2
  * Minimum plugin SDK: 1.12.3
  * Minimum Orthanc runtime: 1.12.3
  * Fix check of Orthanc runtime version
* Tue Mar 19 2024 Axel Braun <axel.braun@gmx.de>
- use gcc13 for Leap > 15.2
* Thu Mar  7 2024 Axel Braun <axel.braun@gmx.de>
- fix build for Leap < 15.6 (no gcc13)
* Thu Mar  7 2024 Max Lin <mlin@suse.com>
- Build orthanc-postgresql with gcc13 on Leap 15
* Wed Feb 21 2024 Axel Braun <axel.braun@gmx.de>
- version 6.1
  * Fixed handling of MaximumStorageSize & MaximumPatientCount.
* Wed Feb 14 2024 Axel Braun <axel.braun@gmx.de>
- version 6.0
  * DB schema revision: 2
  * The DB schema has been updated to Revision 2.  If you need to reinstall the previous
    version of the plugin, you should run this script:
    https://orthanc.uclouvain.be/hg/orthanc-databases/file/tip/PostgreSQL/Plugins/SQL/Downgrades/Rev2ToRev1.sql
  * Transaction Mode:
    Introduced a new configuration "TransactionMode" to select the transaction isolation level.
    Allowed values: "Serializable", "ReadCommitted".
    The "Serializable" mode was the only available value up to now.  It is still the default
    value now.
    The "ReadCommitted" is possible now due to rewrites of SQL queries and notably improves
    the Orthanc ability to ingest data from multiple sources in parallel.
  * New "EnableVerboseLogs" configuration to show SQL statements being executed.
* Tue Jul 11 2023 Axel Braun <axel.braun@gmx.de>
- version 5.1
  * Optimization of LookupResources mainly used in tools/find, C-Find and QIDO-RS.
- version 5.0
  * Compatibility with Orthanc SDK 1.12.0 (communications between the
    Orthanc core and the database plugin using Google Protocol Buffers)
  * Upgraded dependencies for static builds (notably on Windows and LSB):
  - openssl 3.1.0
  * psql114.patch removed (included in source)
* Sun May  9 2021 Axel Braun <axel.braun@gmx.de>
- Version 4.0 (no changelog)
* Mon Dec 14 2020 Axel Braun <axel.braun@gmx.de>
- Version 3.3
  * Added an advisory lock to avoid race conditions during database setup
  * Added "MaximumConnectionRetries" & "ConnectionRetryInterval" to configure
  the retries when connecting to the DB at startup
  * Support of dynamic linking against the system-wide Orthanc framework library
  * build aginst orthanc-framework removed
* Thu Oct 22 2020 Axel Braun <axel.braun@gmx.de>
- switch to orthanc-framework (static version)
  psql114.patch extended for psql 12/13 versions
* Sun Mar 15 2020 Max Lin <mlin@suse.com>
- For Leap version >= 15.2, postgresql-server-devel need to be used
* Mon Aug  5 2019 Axel Braun <axel.braun@gmx.de>
- Version 3.2
  Initial build on OBS
